/**
 * Creating a sidebar enables you to:
 - create an ordered group of docs
 - render a sidebar for each doc of that group
 - provide next/previous navigation

 The sidebars can be generated from the filesystem, or explicitly defined here.

 Create as many sidebars as you want.
 */

// @ts-check

/** @type {import('@docusaurus/plugin-content-docs').SidebarsConfig} */
const sidebars = {
  tutorial: [
    {
      type: "category",
      label: "开始",
      collapsible: false,
      items: ["index", "quick-start", "editor-support"],
    },
    {
      type: "category",
      label: "指南",
      items: [
        {
          type: "autogenerated",
          dirName: "tutorial",
        },
      ],
    },
    {
      type: "category",
      label: "深入",
      items: [
        {
          type: "autogenerated",
          dirName: "appendices",
        },
      ],
    },
    {
      type: "category",
      label: "进阶",
      items: [
        {
          type: "autogenerated",
          dirName: "advanced",
        },
      ],
    },
    {
      type: "category",
      label: "最佳实践",
      items: [
        {
          type: "autogenerated",
          dirName: "best-practice",
        },
      ],
    },
    {
      type: "category",
      label: "开发者",
      items: [
        {
          type: "autogenerated",
          dirName: "developer",
        },
      ],
    },
  ],
  api: [{ type: "autogenerated", dirName: "api" }],
  ecosystem: [
    {
      type: "category",
      label: "关于我们",
      collapsible: false,
      items: [
        {
          type: "autogenerated",
          dirName: "community",
        },
      ],
    },
    {
      type: "category",
      label: "开源之夏",
      collapsible: false,
      items: [
        {
          type: "autogenerated",
          dirName: "ospp",
        },
      ],
    },
    {
      type: "category",
      label: "社区资源",
      collapsible: false,
      items: [
        {
          type: "link",
          label: "商店",
          href: "/store",
        },
        {
          type: "link",
          label: "论坛",
          href: "https://discussions.nonebot.dev",
        },
      ],
    },
  ],
};

module.exports = sidebars;
